# Now I Can Sleep

Minimal settings, markdown-based automated documentation workflow for GitHub repositories.

```txt
Manual workflow:

           ┌──────────>  Make changes  ────────────┐
           |                                       v

    Deploy docs-page                       Update docs-files

           ^                                       │
           └─────────  Rebuild docs-page  <────────┘



With NICS:

           ┌──────────>  Make changes  ────────────┐
           |                                       |
           └─────────  Update docs-files  <────────┘
```

![NICS' banner](https://raw.githubusercontent.com/nvfp/now-i-can-sleep/master/assets/logo200.png)

[![Rebuild docs](https://github.com/nvfp/now-i-can-sleep/actions/workflows/rebuild-docs.yml/badge.svg)](https://github.com/nvfp/now-i-can-sleep/actions/workflows/rebuild-docs.yml)
[![pypi version](https://img.shields.io/pypi/v/nics?logo=pypi)](https://pypi.org/project/nics/)
[![MIT License](https://img.shields.io/badge/license-MIT-blue.svg?style=flat)](http://choosealicense.com/licenses/mit/)


## Installation

1. Install via pip, run `pip install nics`
2. Navigate to your project root folder
3. Run `nics init`
4. Follow the wizard, and you all set!


## Links

- [Documentation](https://nvfp.github.io/now-i-can-sleep)
- [Changelog](https://nvfp.github.io/now-i-can-sleep/changelog)
- [💙Many Thanks](https://nvfp.github.io/now-i-can-sleep/many-thanks)
- [FAQ](https://nvfp.github.io/now-i-can-sleep/faqs)


## Troubleshoot

- To report bugs or ask questions, please open an issue or submit a pull request.


## License

This project is licensed under the MIT license.